# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 65.0.1-v202405012042
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ServerStatusOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'at_user_limit': 'bool',
        'configuration_options': 'list[ConfigurationOptionOutputSimpleV1]',
        'default_max_capsule_duration': 'ScalarValueOutputV1',
        'default_max_interpolation': 'ScalarValueOutputV1',
        'is_data_lab_available': 'bool',
        'priorities': 'list[PriorityV1]',
        'seeq_gpt_enabled': 'bool',
        'server_specs': 'list[ServerSpecOutputV1]',
        'time_zone': 'str',
        'version': 'str'
    }

    attribute_map = {
        'at_user_limit': 'atUserLimit',
        'configuration_options': 'configurationOptions',
        'default_max_capsule_duration': 'defaultMaxCapsuleDuration',
        'default_max_interpolation': 'defaultMaxInterpolation',
        'is_data_lab_available': 'isDataLabAvailable',
        'priorities': 'priorities',
        'seeq_gpt_enabled': 'seeqGptEnabled',
        'server_specs': 'serverSpecs',
        'time_zone': 'timeZone',
        'version': 'version'
    }

    def __init__(self, at_user_limit=False, configuration_options=None, default_max_capsule_duration=None, default_max_interpolation=None, is_data_lab_available=False, priorities=None, seeq_gpt_enabled=False, server_specs=None, time_zone=None, version=None):
        """
        ServerStatusOutputV1 - a model defined in Swagger
        """

        self._at_user_limit = None
        self._configuration_options = None
        self._default_max_capsule_duration = None
        self._default_max_interpolation = None
        self._is_data_lab_available = None
        self._priorities = None
        self._seeq_gpt_enabled = None
        self._server_specs = None
        self._time_zone = None
        self._version = None

        if at_user_limit is not None:
          self.at_user_limit = at_user_limit
        if configuration_options is not None:
          self.configuration_options = configuration_options
        if default_max_capsule_duration is not None:
          self.default_max_capsule_duration = default_max_capsule_duration
        if default_max_interpolation is not None:
          self.default_max_interpolation = default_max_interpolation
        if is_data_lab_available is not None:
          self.is_data_lab_available = is_data_lab_available
        if priorities is not None:
          self.priorities = priorities
        if seeq_gpt_enabled is not None:
          self.seeq_gpt_enabled = seeq_gpt_enabled
        if server_specs is not None:
          self.server_specs = server_specs
        if time_zone is not None:
          self.time_zone = time_zone
        if version is not None:
          self.version = version

    @property
    def at_user_limit(self):
        """
        Gets the at_user_limit of this ServerStatusOutputV1.
        Whether the system is at it's user limit

        :return: The at_user_limit of this ServerStatusOutputV1.
        :rtype: bool
        """
        return self._at_user_limit

    @at_user_limit.setter
    def at_user_limit(self, at_user_limit):
        """
        Sets the at_user_limit of this ServerStatusOutputV1.
        Whether the system is at it's user limit

        :param at_user_limit: The at_user_limit of this ServerStatusOutputV1.
        :type: bool
        """

        self._at_user_limit = at_user_limit

    @property
    def configuration_options(self):
        """
        Gets the configuration_options of this ServerStatusOutputV1.
        A collection of configuration options and their values

        :return: The configuration_options of this ServerStatusOutputV1.
        :rtype: list[ConfigurationOptionOutputSimpleV1]
        """
        return self._configuration_options

    @configuration_options.setter
    def configuration_options(self, configuration_options):
        """
        Sets the configuration_options of this ServerStatusOutputV1.
        A collection of configuration options and their values

        :param configuration_options: The configuration_options of this ServerStatusOutputV1.
        :type: list[ConfigurationOptionOutputSimpleV1]
        """

        self._configuration_options = configuration_options

    @property
    def default_max_capsule_duration(self):
        """
        Gets the default_max_capsule_duration of this ServerStatusOutputV1.

        :return: The default_max_capsule_duration of this ServerStatusOutputV1.
        :rtype: ScalarValueOutputV1
        """
        return self._default_max_capsule_duration

    @default_max_capsule_duration.setter
    def default_max_capsule_duration(self, default_max_capsule_duration):
        """
        Sets the default_max_capsule_duration of this ServerStatusOutputV1.

        :param default_max_capsule_duration: The default_max_capsule_duration of this ServerStatusOutputV1.
        :type: ScalarValueOutputV1
        """

        self._default_max_capsule_duration = default_max_capsule_duration

    @property
    def default_max_interpolation(self):
        """
        Gets the default_max_interpolation of this ServerStatusOutputV1.

        :return: The default_max_interpolation of this ServerStatusOutputV1.
        :rtype: ScalarValueOutputV1
        """
        return self._default_max_interpolation

    @default_max_interpolation.setter
    def default_max_interpolation(self, default_max_interpolation):
        """
        Sets the default_max_interpolation of this ServerStatusOutputV1.

        :param default_max_interpolation: The default_max_interpolation of this ServerStatusOutputV1.
        :type: ScalarValueOutputV1
        """

        self._default_max_interpolation = default_max_interpolation

    @property
    def is_data_lab_available(self):
        """
        Gets the is_data_lab_available of this ServerStatusOutputV1.
        Whether the Network/DataLab/Hostname configuration has been set

        :return: The is_data_lab_available of this ServerStatusOutputV1.
        :rtype: bool
        """
        return self._is_data_lab_available

    @is_data_lab_available.setter
    def is_data_lab_available(self, is_data_lab_available):
        """
        Sets the is_data_lab_available of this ServerStatusOutputV1.
        Whether the Network/DataLab/Hostname configuration has been set

        :param is_data_lab_available: The is_data_lab_available of this ServerStatusOutputV1.
        :type: bool
        """

        self._is_data_lab_available = is_data_lab_available

    @property
    def priorities(self):
        """
        Gets the priorities of this ServerStatusOutputV1.
        The priorities for metrics, sorted descending by level

        :return: The priorities of this ServerStatusOutputV1.
        :rtype: list[PriorityV1]
        """
        return self._priorities

    @priorities.setter
    def priorities(self, priorities):
        """
        Sets the priorities of this ServerStatusOutputV1.
        The priorities for metrics, sorted descending by level

        :param priorities: The priorities of this ServerStatusOutputV1.
        :type: list[PriorityV1]
        """

        self._priorities = priorities

    @property
    def seeq_gpt_enabled(self):
        """
        Gets the seeq_gpt_enabled of this ServerStatusOutputV1.
        Whether the system has been configured to access the Seeq GPT Service

        :return: The seeq_gpt_enabled of this ServerStatusOutputV1.
        :rtype: bool
        """
        return self._seeq_gpt_enabled

    @seeq_gpt_enabled.setter
    def seeq_gpt_enabled(self, seeq_gpt_enabled):
        """
        Sets the seeq_gpt_enabled of this ServerStatusOutputV1.
        Whether the system has been configured to access the Seeq GPT Service

        :param seeq_gpt_enabled: The seeq_gpt_enabled of this ServerStatusOutputV1.
        :type: bool
        """

        self._seeq_gpt_enabled = seeq_gpt_enabled

    @property
    def server_specs(self):
        """
        Gets the server_specs of this ServerStatusOutputV1.
        Information about the specs of the server

        :return: The server_specs of this ServerStatusOutputV1.
        :rtype: list[ServerSpecOutputV1]
        """
        return self._server_specs

    @server_specs.setter
    def server_specs(self, server_specs):
        """
        Sets the server_specs of this ServerStatusOutputV1.
        Information about the specs of the server

        :param server_specs: The server_specs of this ServerStatusOutputV1.
        :type: list[ServerSpecOutputV1]
        """

        self._server_specs = server_specs

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ServerStatusOutputV1.
        UTC offset of the server's current time zone (UTC hh:mm)

        :return: The time_zone of this ServerStatusOutputV1.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ServerStatusOutputV1.
        UTC offset of the server's current time zone (UTC hh:mm)

        :param time_zone: The time_zone of this ServerStatusOutputV1.
        :type: str
        """

        self._time_zone = time_zone

    @property
    def version(self):
        """
        Gets the version of this ServerStatusOutputV1.
        The version of Seeq running on the server

        :return: The version of this ServerStatusOutputV1.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ServerStatusOutputV1.
        The version of Seeq running on the server

        :param version: The version of this ServerStatusOutputV1.
        :type: str
        """

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ServerStatusOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
